<div id="header">
    <h1><a href="{{ site.baseurl }}/index.html"><span>Arbre</span></a></h1>

    <div id="nav">
        <!-- a href="{{ site.baseurl }}/documentation.html">Documentation</a -->
        <a href="http://github.com/activeadmin/arbre">Get the Code</a>
    </div>
</div>
